Learn R Programming

bioLeak (version 0.2.0)

.stationary_bootstrap: Stationary bootstrap indices

Description

Implements the stationary bootstrap of Politis & Romano (1994), which resamples contiguous blocks of variable length to preserve weak temporal dependence while maintaining ergodicity.

Usage

.stationary_bootstrap(idx, mean_block)

Value

Integer vector of permuted indices of the same length as `idx`.

Arguments

idx

Integer vector of ordered indices.

mean_block

Positive numeric, expected block length.

References

Politis, D. N., & Romano, J. P. (1994). *The stationary bootstrap.* Journal of the American Statistical Association, 89(428), 1303-1313.