| .stationary_bootstrap | R Documentation |
Implements the stationary bootstrap of Politis & Romano (1994), which resamples contiguous blocks of variable length to preserve weak temporal dependence while maintaining ergodicity.
.stationary_bootstrap(idx, mean_block)
idx |
Integer vector of ordered indices. |
mean_block |
Positive numeric, expected block length. |
Integer vector of permuted indices of the same length as 'idx'.
Politis, D. N., & Romano, J. P. (1994). *The stationary bootstrap.* Journal of the American Statistical Association, 89(428), 1303-1313.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.