impute_guarded: Leakage-safe data imputation via guarded preprocessing
Description
Fits imputation parameters on the training data only, then applies the same
guarded transformation to the test data. This function is a thin wrapper
around the guarded preprocessing used by fit_resample().
Output is the transformed feature matrix used by the guarded pipeline
(categorical variables are one-hot encoded).